@@ -22,12 +22,12 @@
 
 import threading
 import os
-from stat import ST_MTIME
 import hashlib
 import types
 
 import pyctpp2
 
+from paste.util.converters import asbool
 from pyramid.asset import abspath_from_asset_spec
 from pyramid.interfaces import ITemplateRenderer
 from pyramid.i18n import get_locale_name
@@ -40,14 +40,12 @@ class IPyCTPP2Engine(Interface):
 
 class ITemplate(Interface):
     instance = Attribute("""pyctpp2 Template object""")
-    mtime = Attribute("""Last modified time""")
 
 class PyCTPP2Template(object):
     implements(ITemplate)
 
-    def __init__(self, instance, mtime):
+    def __init__(self, instance):
         self.instance = instance
-        self.mtime = mtime
 
 
 registry_lock = threading.Lock()
@@ -96,6 +94,7 @@ class PyCTPP2TemplateRenderer(object):
         self.path = info.settings.get('pyctpp2.template.path', '')
         self.path = [abspath_from_asset_spec(p) for p in self.path.split()]
         self.engine.path = self.path
+        self.reload_templates = asbool(info.settings.get('reload_templates'))
 
         registry = self.info.registry
         self.tmpl_settings = registry.queryUtility(ITemplateSettings)
@@ -121,11 +120,10 @@ class PyCTPP2TemplateRenderer(object):
         m.update(path)
         ct_key = m.hexdigest()
 
-        last_modified = os.stat(path)[ST_MTIME]
         template = self.info.registry.queryUtility(ITemplate, ct_key)
-        if template is None or template.mtime < os.stat(path)[ST_MTIME]:
+        if not template or self.reload_templates:
             instance = self.engine.parse(path)
-            template = PyCTPP2Template(instance, last_modified)
+            template = PyCTPP2Template(instance)
             self.info.registry.registerUtility(template, ITemplate, ct_key)
 
         return template.instance
